==> huaweicloudsdkconfig-3.1.75-py2.py3-none-any.whl: huaweicloudsdkconfig/v1/model/create_organization_conformance_pack_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateOrganizationConformancePackRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'organization_id': 'str',
        'body': 'OrgConformancePackRequestBody'
    }

    attribute_map = {
        'organization_id': 'organization_id',
        'body': 'body'
    }

    def __init__(self, organization_id=None, body=None):
        """CreateOrganizationConformancePackRequest

        The model defined in huaweicloud sdk

        :param organization_id: 组织ID。
        :type organization_id: str
        :param body: Body of the CreateOrganizationConformancePackRequest
        :type body: :class:`huaweicloudsdkconfig.v1.OrgConformancePackRequestBody`
        """
        
        

        self._organization_id = None
        self._body = None
        self.discriminator = None

        self.organization_id = organization_id
        if body is not None:
            self.body = body

    @property
    def organization_id(self):
        """Gets the organization_id of this CreateOrganizationConformancePackRequest.

        组织ID。

        :return: The organization_id of this CreateOrganizationConformancePackRequest.
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """Sets the organization_id of this CreateOrganizationConformancePackRequest.

        组织ID。

        :param organization_id: The organization_id of this CreateOrganizationConformancePackRequest.
        :type organization_id: str
        """
        self._organization_id = organization_id

    @property
    def body(self):
        """Gets the body of this CreateOrganizationConformancePackRequest.

        :return: The body of this CreateOrganizationConformancePackRequest.
        :rtype: :class:`huaweicloudsdkconfig.v1.OrgConformancePackRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this CreateOrganizationConformancePackRequest.

        :param body: The body of this CreateOrganizationConformancePackRequest.
        :type body: :class:`huaweicloudsdkconfig.v1.OrgConformancePackRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateOrganizationConformancePackRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkconfig-3.1.120-py2.py3-none-any.whl: huaweicloudsdkconfig/v1/model/create_organization_conformance_pack_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateOrganizationConformancePackRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'organization_id': 'str',
        'x_language': 'str',
        'body': 'OrgConformancePackRequestBody'
    }

    attribute_map = {
        'organization_id': 'organization_id',
        'x_language': 'X-Language',
        'body': 'body'
    }

    def __init__(self, organization_id=None, x_language=None, body=None):
        """CreateOrganizationConformancePackRequest

        The model defined in huaweicloud sdk

        :param organization_id: 组织ID。
        :type organization_id: str
        :param x_language: 组织合规包信息语言，默认为\&quot;en-us\&quot;英文
        :type x_language: str
        :param body: Body of the CreateOrganizationConformancePackRequest
        :type body: :class:`huaweicloudsdkconfig.v1.OrgConformancePackRequestBody`
        """
        
        

        self._organization_id = None
        self._x_language = None
        self._body = None
        self.discriminator = None

        self.organization_id = organization_id
        if x_language is not None:
            self.x_language = x_language
        if body is not None:
            self.body = body

    @property
    def organization_id(self):
        """Gets the organization_id of this CreateOrganizationConformancePackRequest.

        组织ID。

        :return: The organization_id of this CreateOrganizationConformancePackRequest.
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """Sets the organization_id of this CreateOrganizationConformancePackRequest.

        组织ID。

        :param organization_id: The organization_id of this CreateOrganizationConformancePackRequest.
        :type organization_id: str
        """
        self._organization_id = organization_id

    @property
    def x_language(self):
        """Gets the x_language of this CreateOrganizationConformancePackRequest.

        组织合规包信息语言，默认为\"en-us\"英文

        :return: The x_language of this CreateOrganizationConformancePackRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        """Sets the x_language of this CreateOrganizationConformancePackRequest.

        组织合规包信息语言，默认为\"en-us\"英文

        :param x_language: The x_language of this CreateOrganizationConformancePackRequest.
        :type x_language: str
        """
        self._x_language = x_language

    @property
    def body(self):
        """Gets the body of this CreateOrganizationConformancePackRequest.

        :return: The body of this CreateOrganizationConformancePackRequest.
        :rtype: :class:`huaweicloudsdkconfig.v1.OrgConformancePackRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this CreateOrganizationConformancePackRequest.

        :param body: The body of this CreateOrganizationConformancePackRequest.
        :type body: :class:`huaweicloudsdkconfig.v1.OrgConformancePackRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateOrganizationConformancePackRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
